@@ -1,7 +1,7 @@
 /*
  * This file is part of the Shiboken Python Bindings Generator project.
  *
- * Copyright (C) 2009-2012 Nokia Corporation and/or its subsidiary(-ies).
+ * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
  *
  * Contact: PySide team <contact@pyside.org>
  *
@@ -314,7 +314,7 @@ QString ShibokenGenerator::fullPythonFunctionName(const AbstractMetaFunction* fu
 
 QString ShibokenGenerator::protectedEnumSurrogateName(const AbstractMetaEnum* metaEnum)
 {
-    return metaEnum->fullName().replace(".", "_") + "_Surrogate";
+    return metaEnum->fullName().replace(".", "_").replace("::", "_") + "_Surrogate";
 }
 
 QString ShibokenGenerator::protectedFieldGetterName(const AbstractMetaField* field)
@@ -1452,9 +1452,9 @@ ShibokenGenerator::ArgumentVarReplacementList ShibokenGenerator::getArgumentRepl
             bool argRemoved = func->argumentRemoved(i+1);
             removed = removed + (int) argRemoved;
             if (argRemoved && hasConversionRule)
-                argValue = QString("%1"CONV_RULE_OUT_VAR_SUFFIX).arg(arg->name());
+                argValue = QString("%1" CONV_RULE_OUT_VAR_SUFFIX).arg(arg->name());
             else if (argRemoved || (lastArg && arg->argumentIndex() > lastArg->argumentIndex()))
-                argValue = QString(CPP_ARG_REMOVED"%1").arg(i);
+                argValue = QString(CPP_ARG_REMOVED "%1").arg(i);
             if (!argRemoved && argValue.isEmpty()) {
                 int argPos = i - removed;
                 const AbstractMetaType* type = arg->type();
@@ -1465,11 +1465,11 @@ ShibokenGenerator::ArgumentVarReplacementList ShibokenGenerator::getArgumentRepl
                         type = builtType;
                 }
                 if (type->typeEntry()->isCustom()) {
-                    argValue = usePyArgs ? QString(PYTHON_ARGS"[%1]").arg(argPos) : PYTHON_ARG;
+                    argValue = usePyArgs ? QString(PYTHON_ARGS "[%1]").arg(argPos) : PYTHON_ARG;
                 } else {
                     argValue = hasConversionRule
-                               ? QString("%1"CONV_RULE_OUT_VAR_SUFFIX).arg(arg->name())
-                               : QString(CPP_ARG"%1").arg(argPos);
+                               ? QString("%1" CONV_RULE_OUT_VAR_SUFFIX).arg(arg->name())
+                               : QString(CPP_ARG "%1").arg(argPos);
                     if (isWrapperType(type)) {
                         if (type->isReference() && !isPointer(type))
                             argValue.prepend('*');
